==> lasem-0.3.2.tar.xz: lasem-0.3.2/src/lsmsvgenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef LSM_SVG_ENUM_TYPES_H
#define LSM_SVG_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "lsmsvgenums.h" */

#define LSM_TYPE_SVG_ANGLE_TYPE	(lsm_svg_angle_type_get_type())
GType lsm_svg_angle_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_PAINT_TYPE	(lsm_svg_paint_type_get_type())
GType lsm_svg_paint_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LENGTH_DIRECTION	(lsm_svg_length_direction_get_type())
GType lsm_svg_length_direction_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LENGTH_TYPE	(lsm_svg_length_type_get_type())
GType lsm_svg_length_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FILL_RULE	(lsm_svg_fill_rule_get_type())
GType lsm_svg_fill_rule_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LINE_JOIN	(lsm_svg_line_join_get_type())
GType lsm_svg_line_join_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LINE_CAP	(lsm_svg_line_cap_get_type())
GType lsm_svg_line_cap_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_TRANSFORM_TYPE	(lsm_svg_transform_type_get_type())
GType lsm_svg_transform_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_PATTERN_UNITS	(lsm_svg_pattern_units_get_type())
GType lsm_svg_pattern_units_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_MARKER_UNITS	(lsm_svg_marker_units_get_type())
GType lsm_svg_marker_units_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_SPREAD_METHOD	(lsm_svg_spread_method_get_type())
GType lsm_svg_spread_method_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_ALIGN	(lsm_svg_align_get_type())
GType lsm_svg_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_MEET_OR_SLICE	(lsm_svg_meet_or_slice_get_type())
GType lsm_svg_meet_or_slice_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_COMP_OP	(lsm_svg_comp_op_get_type())
GType lsm_svg_comp_op_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_STRETCH	(lsm_svg_font_stretch_get_type())
GType lsm_svg_font_stretch_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_STYLE	(lsm_svg_font_style_get_type())
GType lsm_svg_font_style_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_WEIGHT	(lsm_svg_font_weight_get_type())
GType lsm_svg_font_weight_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_TEXT_ANCHOR	(lsm_svg_text_anchor_get_type())
GType lsm_svg_text_anchor_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FILTER_INPUT	(lsm_svg_filter_input_get_type())
GType lsm_svg_filter_input_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_DISPLAY	(lsm_svg_display_get_type())
GType lsm_svg_display_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_VISIBILITY	(lsm_svg_visibility_get_type())
GType lsm_svg_visibility_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_ELEMENT_CATEGORY	(lsm_svg_element_category_get_type())
GType lsm_svg_element_category_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvgview.h" */

#define LSM_TYPE_SVG_VIEW_SURFACE_TYPE	(lsm_svg_view_surface_type_get_type())
GType lsm_svg_view_surface_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvgmatrix.h" */

#define LSM_TYPE_SVG_MATRIX_FLAGS	(lsm_svg_matrix_flags_get_type())
GType lsm_svg_matrix_flags_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvguseelement.h" */

#define LSM_TYPE_SVG_USE_ELEMENT_FLAGS	(lsm_svg_use_element_flags_get_type())
GType lsm_svg_use_element_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* LSM_SVG_ENUM_TYPES_H */

/* Generated data ends here */

==> lasem-0.3.3.tar.xz: lasem-0.3.3/src/lsmsvgenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef LSM_SVG_ENUM_TYPES_H
#define LSM_SVG_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "lsmsvgenums.h" */

#define LSM_TYPE_SVG_ANGLE_TYPE	(lsm_svg_angle_type_get_type())
GType lsm_svg_angle_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_BLENDING_MODE	(lsm_svg_blending_mode_get_type())
GType lsm_svg_blending_mode_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_PAINT_TYPE	(lsm_svg_paint_type_get_type())
GType lsm_svg_paint_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LENGTH_DIRECTION	(lsm_svg_length_direction_get_type())
GType lsm_svg_length_direction_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LENGTH_TYPE	(lsm_svg_length_type_get_type())
GType lsm_svg_length_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FILL_RULE	(lsm_svg_fill_rule_get_type())
GType lsm_svg_fill_rule_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LINE_JOIN	(lsm_svg_line_join_get_type())
GType lsm_svg_line_join_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_LINE_CAP	(lsm_svg_line_cap_get_type())
GType lsm_svg_line_cap_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_TRANSFORM_TYPE	(lsm_svg_transform_type_get_type())
GType lsm_svg_transform_type_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_OVERFLOW	(lsm_svg_overflow_get_type())
GType lsm_svg_overflow_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_PATTERN_UNITS	(lsm_svg_pattern_units_get_type())
GType lsm_svg_pattern_units_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_MARKER_UNITS	(lsm_svg_marker_units_get_type())
GType lsm_svg_marker_units_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_SPREAD_METHOD	(lsm_svg_spread_method_get_type())
GType lsm_svg_spread_method_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_ALIGN	(lsm_svg_align_get_type())
GType lsm_svg_align_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_MEET_OR_SLICE	(lsm_svg_meet_or_slice_get_type())
GType lsm_svg_meet_or_slice_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_COMP_OP	(lsm_svg_comp_op_get_type())
GType lsm_svg_comp_op_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_STRETCH	(lsm_svg_font_stretch_get_type())
GType lsm_svg_font_stretch_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_STYLE	(lsm_svg_font_style_get_type())
GType lsm_svg_font_style_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FONT_WEIGHT	(lsm_svg_font_weight_get_type())
GType lsm_svg_font_weight_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_TEXT_ANCHOR	(lsm_svg_text_anchor_get_type())
GType lsm_svg_text_anchor_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_FILTER_INPUT	(lsm_svg_filter_input_get_type())
GType lsm_svg_filter_input_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_DISPLAY	(lsm_svg_display_get_type())
GType lsm_svg_display_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_VISIBILITY	(lsm_svg_visibility_get_type())
GType lsm_svg_visibility_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_ELEMENT_CATEGORY	(lsm_svg_element_category_get_type())
GType lsm_svg_element_category_get_type	(void) G_GNUC_CONST;

#define LSM_TYPE_SVG_WRITING_MODE	(lsm_svg_writing_mode_get_type())
GType lsm_svg_writing_mode_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvgview.h" */

#define LSM_TYPE_SVG_VIEW_SURFACE_TYPE	(lsm_svg_view_surface_type_get_type())
GType lsm_svg_view_surface_type_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvgmatrix.h" */

#define LSM_TYPE_SVG_MATRIX_FLAGS	(lsm_svg_matrix_flags_get_type())
GType lsm_svg_matrix_flags_get_type	(void) G_GNUC_CONST;

/* Enumerations from "lsmsvguseelement.h" */

#define LSM_TYPE_SVG_USE_ELEMENT_FLAGS	(lsm_svg_use_element_flags_get_type())
GType lsm_svg_use_element_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* LSM_SVG_ENUM_TYPES_H */

/* Generated data ends here */
